package dst.net.droid;

import java.io.ByteArrayOutputStream;
import java.io.UnsupportedEncodingException;
import java.sql.SQLException;
import java.util.ArrayList;

import dst.net.jsonObj.EmployeeImage;
import dst.net.jsonObj.GenericResult;
import android.app.Activity;
import android.content.Context;
import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.Bitmap.CompressFormat;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.PorterDuff.Mode;
import android.graphics.PorterDuffXfermode;
import android.graphics.Rect;
import android.graphics.RectF;
import android.util.Log;
import android.view.Display;
import android.view.View;
import android.view.ViewGroup;
import android.view.animation.Animation;
import android.view.animation.AnimationUtils;
import android.widget.BaseAdapter;
import android.widget.ImageView;

public class EmployeeImageAdapter extends BaseAdapter 
{    
	private Context mContext;
	private ArrayList<GenericResult>  _employees;
	private int _selectedPos;
	
	
	public EmployeeImageAdapter(ArrayList<GenericResult> emp , Context c) throws UnsupportedEncodingException, SQLException 
	{
		System.gc();
  
		mContext = c;
		_employees = emp;

	} 
	public int getCount() 
	{       
		return _employees.size(); 
	}  
	public Object getItem(int position)
	{       
		return _employees.get(position); 
	}   
	public long getItemId(int position)
	{     
		return _employees.get(position).Result;
	}  
	public String getItemDescription(int position)
	{        
		GenericResult i =  _employees.get(position);
		
		return i.Description;
	}  
	public int gettSelectedID(){
    	
    	if (_selectedPos>-1)
    	{
    		return _employees.get(_selectedPos).Result;
    	}
    	else
    		return -1;
	}
	
	public void setSelectedPosition(int pos){
    	_selectedPos = pos;
		// inform the view of this change
		notifyDataSetChanged();
	}
	
	// create a new ImageView for each item referenced by the Adapter 
	public View getView(final int position, View convertView, ViewGroup parent) 
	{     
        final ImageView imageView;        

        final EmployeeImage it = Employee.EmployeeImageMap.get(_employees.get(position).Result); // (ItemDataNode) getItem(position);
        
        if (convertView == null) 
        {
        	// if it's not recycled, initialize some attributes            
        	imageView = new ImageView(mContext);

        	imageView.setScaleType(ImageView.ScaleType.CENTER_CROP);            
        	imageView.setPadding(2,2,2, 2);
        }  
        else  //Cached Imagest
        {            
        	imageView = (ImageView) convertView;    
            /*************/
        } 
        
        Bitmap bm = null;
    	
		Display display = ((Activity) mContext).getWindowManager().getDefaultDisplay();  
		int width = (display.getWidth() / 4)  - 15;
		int height = (int)(width*1.25);

    		Log.i("getView()","Image Not in CACHE" );

        	byte[] image = null;
        	
    		try {
    				image  = Employee.GetImage(it.Number);
    				Bitmap bmp;
    				if (image==null)  //Article no has image
    				{
    					// Get size from folder resource
    					bmp = Bitmap.createBitmap(width, height, Bitmap.Config.ARGB_8888); // this creates a MUTABLE bitmap 
    					Canvas canvas = new Canvas(bmp); 

    					RectF rect = new RectF(0,0,width,height);   
    					
    					Paint paint = new Paint();
    					paint.setStyle(Paint.Style.FILL);

    					paint.setAntiAlias(true);
    					paint.setColor(Color.parseColor(it.BackColor));
    					canvas.drawRect(rect, paint);
    					
    					bmp = drawTextToBitmapAtMiddle(mContext, bmp ,it.Description);
    				}
    				else
    				{	
    					bmp =  Bitmap.createScaledBitmap(BitmapFactory.decodeByteArray(image,0,image.length),  width, height, true);
    					bmp = drawTextToBitmapAtBottom(mContext, bmp ,it.Description);
    				}
    				

    	            	if(_selectedPos == position)
    	            	{
    	            		Animation rotate = AnimationUtils.loadAnimation(mContext, R.anim.scale_alpha);
    	            		
    	           			imageView.startAnimation(rotate); 
    	           			imageView.setAlpha(255);
    	           			
    	           			Canvas canvas = new Canvas(bmp);

        	            	Paint paint = new Paint();
        	            	paint.setStyle(Paint.Style.FILL);
        	            	paint.setAntiAlias(true);
        	            	paint.setColor(Color.GREEN);
        	            		

        	            	RectF rect =  new RectF(0,0 ,bmp.getWidth(),(int)(bmp.getHeight()*0.1));
        					
        	            	canvas.drawRect(rect, paint);

    	            	}
    	            	else
    	            		imageView.setAlpha(180);
    	            	

   	            	//Round Image
    				Bitmap bitmapRounded = getRoundedCornerBitmap(bmp,8);

    				ByteArrayOutputStream bos = new ByteArrayOutputStream();   
    				bitmapRounded.compress(CompressFormat.JPEG,80,bos);   
    				
    				image  =  bos.toByteArray();
    		

    		} catch (Exception e) {
    			
    			AndroidOperations.AppendLog("EmployeeImageAdapter:" + e.getMessage());
    		}          
            
            if (image!= null)
            {
            	bm = BitmapFactory.decodeByteArray(image, 0, image.length); 
            } 


            
    	imageView.setImageBitmap(bm);
        
        
        return imageView;
	}
	
		
	public Bitmap drawTextToBitmapAtBottom(Context gContext, Bitmap bitmap , String gText1) {
		
		Resources resources = gContext.getResources();
		float scale = resources.getDisplayMetrics().density;
		  
		android.graphics.Bitmap.Config bitmapConfig = bitmap.getConfig();
			  // set default bitmap config if none
			  if(bitmapConfig == null) {
			    bitmapConfig = android.graphics.Bitmap.Config.ARGB_8888;
			  }
			  // resource bitmaps are imutable, 
			  // so we need to convert it to mutable one
			  bitmap = bitmap.copy(bitmapConfig, true);

			  // new antialised Paint
			  Paint paint1 = new Paint(Paint.ANTI_ALIAS_FLAG);
			  // text color - #3D3D3D
			  paint1.setColor(Color.rgb(0, 0, 0));
			  // text size in pixels
		  
			  paint1.setTextSize((int)14 * scale);

			  Rect bounds = new Rect();
	  
			  paint1.getTextBounds(gText1, 0, gText1.length(), bounds);
		
			  int x = 0;// (bitmap.getWidth() - bounds.width())/2;
			  int xText =(bitmap.getWidth()/2) - (bounds.width()/2);
			  int y = bitmap.getHeight() - bounds.height()-5;
			  int yText = bitmap.getHeight() -2;
			  			 
			  Canvas canvas = new Canvas(bitmap);

			  Paint paint = new Paint();
			  paint.setStyle(Paint.Style.FILL);
			  paint.setAntiAlias(true);
			  paint.setColor(Color.WHITE);
			  
			  RectF rect =  new RectF(x,y ,bitmap.getWidth(),bitmap.getHeight());
				
			  if (gText1.length()>0)
				  canvas.drawRect(rect, paint);

			  canvas.drawText(gText1, xText  , yText  , paint1);
			 
			  return bitmap;
	}
	
	public Bitmap drawTextToBitmapAtMiddle(Context gContext, Bitmap bitmap , String gText1) {
		
		Resources resources = gContext.getResources();
		float scale = resources.getDisplayMetrics().density;
		  
		android.graphics.Bitmap.Config bitmapConfig = bitmap.getConfig();
			  // set default bitmap config if none
			  if(bitmapConfig == null) {
			    bitmapConfig = android.graphics.Bitmap.Config.ARGB_8888;
			  }
			  // resource bitmaps are imutable, 
			  // so we need to convert it to mutable one
			  bitmap = bitmap.copy(bitmapConfig, true);

			  // new antialised Paint
			  Paint paint1 = new Paint(Paint.ANTI_ALIAS_FLAG);
			  // text color - #3D3D3D
			  paint1.setColor(Color.rgb(0, 0, 0));
			  // text size in pixels
		  
			  paint1.setTextSize((int)14* scale);
			  // text shadow
			  /*paint1.setShadowLayer(1f, 0f, 1f, Color.WHITE);
			  paint2.setShadowLayer(1f, 0f, 1f, Color.WHITE);
			  paint3.setShadowLayer(1f, 0f, 1f, Color.WHITE);
			  paint4.setShadowLayer(1f, 0f, 1f, Color.WHITE);
			 */
			  // draw text to the Canvas center
			  Rect bounds = new Rect();
	  
			  paint1.getTextBounds(gText1, 0, gText1.length(), bounds);
		
			  int x = 0;// (bitmap.getWidth() - bounds.width())/2;
			  int xText =(bitmap.getWidth()/2) - (bounds.width()/2);
			  
			  int y = bitmap.getHeight()/2 - bounds.height()-5;
			  int yText = bitmap.getHeight()/2 + (bounds.height()/2) ;
			  			 
			  Canvas canvas = new Canvas(bitmap);

			  Paint paint = new Paint();
			  paint.setStyle(Paint.Style.FILL);
			  paint.setAntiAlias(true);
			  paint.setColor(Color.WHITE);
			  
			  RectF rect =  new RectF(x,y ,bitmap.getWidth(),(bitmap.getHeight()/2)+ bounds.height()+5);
				
			  if (gText1.length()>0)
				  canvas.drawRect(rect, paint);

			  canvas.drawText(gText1, xText  , yText  , paint1);
			 
			  return bitmap;
	}

	public Bitmap getRoundedCornerBitmap(Bitmap bitmap, int pixels) { 
        Bitmap output = Bitmap.createBitmap(bitmap.getWidth(), bitmap 
                .getHeight(), Bitmap.Config.ARGB_8888); 
        Canvas canvas = new Canvas(output); 
 
        //final int color = 0xff424242; 
        final int color = 0xffffffff;
        
        final Paint paint = new Paint(); 
        final Rect rect = new Rect(0, 0, bitmap.getWidth(), bitmap.getHeight()); 
        final RectF rectF = new RectF(rect); 
        final float roundPx = pixels; 
 
        paint.setAntiAlias(true); 
        canvas.drawARGB(0, 0, 0, 0); 
        paint.setColor(color); 
        canvas.drawRoundRect(rectF, roundPx, roundPx, paint); 
 
        paint.setXfermode(new PorterDuffXfermode(Mode.SRC_IN)); 
        canvas.drawBitmap(bitmap, rect, rect, paint); 
 
        return output; 
    }
}

